#ifndef ESP32_STORAGE_HPP
#define ESP32_STORAGE_HPP

#ifdef ESP32
#include "Preferences.h"
#include "SPIFFS.h"
#elif defined(ESP8266)
#include "EEPROM.h"
#include "spiffs_api.h"
#endif

#include "Utils.hpp"

namespace fw
{
    class Storage
    {
    private:
#ifdef ESP32
        Preferences memory;
#elif defined(ESP8266)
        uint16_t eeprom_size = 1000;
        uint8_t security_number = 93;
        uint16_t eeprom_settings_head = 0;
        uint16_t eeprom_rules_head = 10;
#endif
        ok_t mount_spiffs();
        ok_t setup_eeprom();

    protected:
        uint8_t retrieve_settings_value(const char *);
        void store_settings_value(const char *, const uint8_t);

        firewall_rule_t *retrieve_firewall_rule(const uint8_t);
        void store_all_firewall_rules(firewall_rule_t *);
        void store_firewall_rule(firewall_rule_t *);

        // httpsserver::SSLCert *retrieve_certificate();
        // void store_certificate(httpsserver::SSLCert *);

    public:
        Storage();
        ~Storage();
    };
}

#endif
